[Freeswitch-svn] [commit] r12383 - in freeswitch/trunk/libs/sofia-sip: . libsofia-sip-ua/nta

FreeSWITCH SVN mikej at freeswitch.org
Tue Mar 3 09:23:31 PST 2009


Author: mikej
Date: Tue Mar  3 11:23:31 2009
New Revision: 12383

Log:
Tue Mar  3 10:49:51 CST 2009  Pekka Pessi <first.last at nokia.com>
  * test_nta.c: timer C now CANCELs INVITE transaction
  Ignore-this: 8de2e5747e7ae0e62e2d8ad9aeb0cbed
  
  408 response is not generated (unless CANCEL times out, too.)



Modified:
   freeswitch/trunk/libs/sofia-sip/.update
   freeswitch/trunk/libs/sofia-sip/libsofia-sip-ua/nta/test_nta.c

Modified: freeswitch/trunk/libs/sofia-sip/.update
==============================================================================
--- freeswitch/trunk/libs/sofia-sip/.update	(original)
+++ freeswitch/trunk/libs/sofia-sip/.update	Tue Mar  3 11:23:31 2009
@@ -1 +1 @@
-Tue Mar  3 11:22:42 CST 2009
+Tue Mar  3 11:23:11 CST 2009

Modified: freeswitch/trunk/libs/sofia-sip/libsofia-sip-ua/nta/test_nta.c
==============================================================================
--- freeswitch/trunk/libs/sofia-sip/libsofia-sip-ua/nta/test_nta.c	(original)
+++ freeswitch/trunk/libs/sofia-sip/libsofia-sip-ua/nta/test_nta.c	Tue Mar  3 11:23:31 2009
@@ -530,7 +530,7 @@
 {
   agent_t *ag = c->c_ag;
 
-  for (ag->ag_canceled = 0; !ag->ag_canceled;) {
+  for (ag->ag_canceled = 0; !ag->ag_canceled || c->c_status < 200;) {
     if (tstflags & tst_verbatim) {
       fputs(".", stdout); fflush(stdout);
     }
@@ -3612,8 +3612,9 @@
 				SIPTAG_PAYLOAD(sdp),
 				TAG_END()));
 
-    /* Run until 1) server gets CANCEL and 2) client gets 408 */
-    TEST_1(!client_run_until_canceled(ctx, 408));
+    /* Run until 1) server gets CANCEL and 2) client gets 487 */
+    /* Note: this has been changed in 1.12.11 */
+    TEST_1(!client_run_until_canceled(ctx, 487));
 
     TEST_1(ag->ag_canceled != 0);
     TEST_P(ag->ag_latest_leg, ag->ag_server_leg);



More information about the Freeswitch-svn mailing list